@@ -65,7 +65,7 @@ const char *cddbpath="/var/lib/cddb";  // default local cddb path
 //#define DEBUG_CDFS  // debug cdfs parsing
 //#define GUARD_DEBUG // enable framebuffer guard
 
-#ifdef DEBUG_CDFS
+#if !defined(NO_DEBUG) && defined(DEBUG_CDFS)
 #define dc(x) { (x); }
 #else
 #define dc(x) ; 
@@ -830,7 +830,7 @@ bool cSndInfo::DoScan(bool KeepOpen)
     Set(dat); dat->Unlock();
     if(!DecoderID) {
       DecoderID=DEC_SND;
-      InfoCache.Cache(this,file,true);
+      InfoCache.Cache(this,file);
       }
     return Abort(true);
     }
