@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2007 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -107,8 +107,7 @@ cMenuBrowse::cMenuBrowse(cFileSource *Source, bool Dirselect, bool WithID3, cons
   excl=Excl;
 
   SetSource(Source); 
-  LoadDir(currentdir);
-  SetButtons();
+  NewDir(currentdir);
 }
 
 cMenuBrowse::~cMenuBrowse()
@@ -157,7 +156,12 @@ bool cMenuBrowse::LoadDir(const char *dir)
 bool cMenuBrowse::NewDir(const char *dir)
 {
   char *ncur=dir ? strdup(dir):0;
-  if(LoadDir(ncur)) {
+  bool r=LoadDir(ncur);
+  if(!r && ncur) {
+    free(ncur); ncur=0;
+    r=LoadDir(ncur);
+    }
+  if(r) {
     free(currentdir); currentdir=ncur;
 
     cFileObj *item=CurrentItem();
