@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2006 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2007 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #include <getopt.h>
 #include <malloc.h>
 #include <stdlib.h>
+#include <ctype.h>
 
 #include "common.h"
 
@@ -75,6 +76,8 @@ public:
 const char *sourcesSub=0;
 cFileSources MPlaySources;
 
+static const char *plugin_name=0;
+
 // --- cMenuSetupMPlayer --------------------------------------------------------
 
 class cMenuSetupMPlayer : public cMenuSetupPage {
@@ -232,7 +235,12 @@ void cMPlayerControl::Hide(void)
 #else
     Interface->Close();
 #endif
-    needsFastResponse=visible=modeOnly=false;
+    visible=modeOnly=false;
+#if APIVERSNUM >= 10500
+    SetNeedsFastResponse(false);
+#else
+    needsFastResponse=false;
+#endif
     }
 }
 
@@ -303,7 +311,12 @@ void cMPlayerControl::ShowProgress(void)
       Interface->Clear();
       if(MPlayerSetup.OsdPos>0) Interface->Fill(0,3,Interface->Width(),MPlayerSetup.OsdPos,clrTransparent);
 #endif
-      needsFastResponse=visible=true; modeOnly=false;
+      visible=true; modeOnly=false;
+#if APIVERSNUM >= 10500
+      SetNeedsFastResponse(true);
+#else
+      needsFastResponse=true;
+#endif
       lastCurrent=lastTotal=-1;
       flush=true;
       }
@@ -405,7 +418,7 @@ void cMPlayerControl::ShowMode(void)
 void cMPlayerControl::JumpDisplay(void)
 {
   char buf[64];
-  const char *j=tr("Jump: "), u=jumpmode?'%':'m';
+  const char *j=trVDR("Jump: "), u=jumpmode?'%':'m';
   if(!jumpval) sprintf(buf,"%s- %c",  j,u);
   else         sprintf(buf,"%s%d- %c",j,jumpval,u);
 #if APIVERSNUM >= 10307
@@ -528,7 +541,7 @@ eOSState cMPlayerControl::ProcessKey(eKeys Key)
       case kBack:
 #if APIVERSNUM >= 10332
                      Hide();
-                     cRemote::CallPlugin(i18n_name);
+                     cRemote::CallPlugin(plugin_name);
                      return osBack;
 #endif
       case kStop:
@@ -618,7 +631,7 @@ void cMenuMPlayBrowse::SetButtons(void)
 {
   static char blue[12];
   snprintf(blue,sizeof(blue),MPlayerAid>=0 ? "AID:%d" : "AID:def",MPlayerAid);
-  SetHelp(tr(BUTTON"Play"), MPlayerSetup.ResumeMode ? tr(BUTTON"Rewind"):0, tr("Source"), blue);
+  SetHelp(trVDR(BUTTON"Play"), MPlayerSetup.ResumeMode ? trVDR(BUTTON"Rewind"):0, tr("Source"), blue);
   Display();
 }
 
@@ -716,7 +729,7 @@ eOSState cMenuMPlayBrowse::ProcessKey(eKeys Key)
 // --- cPluginMPlayer ----------------------------------------------------------
 
 static const char *VERSION        = PLUGIN_VERSION;
-static const char *DESCRIPTION    = "Media replay via MPlayer";
+static const char *DESCRIPTION    = trNOOP("Media replay via MPlayer");
 static const char *MAINMENUENTRY  = "MPlayer";
 
 class cPluginMPlayer : public cPlugin {
@@ -813,14 +826,21 @@ bool cPluginMPlayer::Start(void)
 #endif
 {
   if(!CheckVDRVersion(1,1,16,"mplayer")) return false;
-  i18n_name=Name();
+  plugin_name="mplayer";
+#if APIVERSNUM < 10507
+  i18n_name="mplayer";
+#else
+  i18n_name="vdr-mplayer";
+#endif
   MPlaySources.Load(AddDirectory(ConfigDirectory(sourcesSub),"mplayersources.conf"));
   if(MPlaySources.Count()<1) {
     esyslog("ERROR: you must have defined at least one source in mplayersources.conf");
     fprintf(stderr,"No source(s) defined in mplayersources.conf\n");
     return false;
     }
+#if APIVERSNUM < 10507
   RegisterI18n(Phrases);
+#endif
   if(!(status=new cMPlayerStatus)) return false;
   return true;
 }
